View Source Membrane.RTP.VP8.Payloader (Membrane RTP VP8 Plugin v0.6.1)
Payloads VP8 frames into RTP packets according to: https://tools.ietf.org/html/rfc7741
element-options
Element options
Passed via struct Membrane.RTP.VP8.Payloader.t/0
max_payload_sizenon_neg_integer()Default value:
1400
Maximal size of outputted payloads in bytes. RTP packet will contain VP8 payload descriptor which can have max: 6B. The resulting RTP packet will also RTP header (min 12B). After adding UDP header (8B), IPv4 header(min 20B, max 60B) everything should fit in standard MTU size (1500B)payload_descriptor_type:simpleDefault value:
:simple
When set to :simple payloader will generate only minimal payload descriptors required for fragmentation. More complex payload descriptors are not yet supported so this option should be left as default.
pads
Pads
input
:input
| Availability | :always |
| Caps | Membrane.RemoteStream, restrictions:content_format: Membrane.VP8,type: :packetized |
| Demand mode | :manual |
| Demand unit | :buffers |
| Direction | :input |
| Mode | :pull |
| Name | :input |
output
:output
| Availability | :always |
| Caps | Membrane.RTP |
| Demand mode | :manual |
| Demand unit | :buffers |
| Direction | :output |
| Mode | :pull |
| Name | :output |
Link to this section Summary
Types
Struct containing options for Membrane.RTP.VP8.Payloader
Functions
Returns pads descriptions for Membrane.RTP.VP8.Payloader
Returns description of options available for this module
Link to this section Types
@type t() :: %Membrane.RTP.VP8.Payloader{ max_payload_size: non_neg_integer(), payload_descriptor_type: :simple }
Struct containing options for Membrane.RTP.VP8.Payloader
Link to this section Functions
@spec membrane_pads() :: [{Membrane.Pad.name_t(), Membrane.Pad.description_t()}]
Returns pads descriptions for Membrane.RTP.VP8.Payloader
@spec options() :: keyword()
Returns description of options available for this module