Membrane.RTP.VP8.Payloader (Membrane RTP VP8 Plugin v0.3.0) View Source
Payloads VP8 frames into RTP packets according to: https://tools.ietf.org/html/rfc7741
Element options
Passed via struct Membrane.RTP.VP8.Payloader.t/0
max_payload_sizenon_neg_integer()Default value:
1400
Maximal size of outputted payloads in bytes. RTP packet will contain VP8 payload descriptor which can have max: 6B. The resulting RTP packet will also RTP header (min 12B). After adding UDP header (8B), IPv4 header(min 20B, max 60B) everything should fit in standard MTU size (1500B)payload_descriptor_type:simpleDefault value:
:simple
When set to :simple payloader will generate only minimal payload descriptors required for fragmentation. More complex payload descriptors are not yet supported so this option should be left as default.
Pads
:input
| Availability | :always |
| Caps | Membrane.RemoteStream, restrictions:<br /> content_format: Membrane.VP8,<br /> type: :packetized |
| Demand unit | :buffers |
| Direction | :input |
| Mode | :pull |
| Name | :input |
:output
| Availability | :always |
| Caps | Membrane.RTP |
| Direction | :output |
| Mode | :pull |
| Name | :output |
Link to this section Summary
Types
Struct containing options for Membrane.RTP.VP8.Payloader
Functions
Returns pads descriptions for Membrane.RTP.VP8.Payloader
Returns description of options available for this module
Link to this section Types
Specs
t() :: %Membrane.RTP.VP8.Payloader{
max_payload_size: non_neg_integer(),
payload_descriptor_type: :simple
}
Struct containing options for Membrane.RTP.VP8.Payloader
Link to this section Functions
Specs
membrane_pads() :: [{Membrane.Pad.name_t(), Membrane.Pad.description_t()}]
Returns pads descriptions for Membrane.RTP.VP8.Payloader
Specs
options() :: keyword()
Returns description of options available for this module